SWDEV-455869 - hip and hsa runtime cannot detect uninitialized pointer
Change-Id: I93459f5d8b7dd4ed7aecf84703ba9aa796777038
[ROCm/hip-tests commit: 8676d3637a]
Bu işleme şunda yer alıyor:
işlemeyi yapan:
Anusha Godavarthy Surya
ebeveyn
500a08991d
işleme
9139122063
@@ -233,18 +233,11 @@ TEST_CASE("Unit_hipMemPrefetchAsyncNegativeTst") {
|
||||
hipStream_t strm;
|
||||
HIP_CHECK(hipStreamCreate(&strm));
|
||||
SECTION("Passing null for dev ptr") {
|
||||
int *Ptr;
|
||||
err = hipMemPrefetchAsync(NULL, MemSz, 0, strm);
|
||||
if (err == hipSuccess) {
|
||||
WARN("hipMemPrefetchAsync() gives hipSuccess when NULL is passed!!");
|
||||
IfTestPassed = false;
|
||||
}
|
||||
err = hipMemPrefetchAsync(Ptr, MemSz, 0, strm);
|
||||
if (err == hipSuccess) {
|
||||
WARN("hipMemPrefetchAsync() gives hipSuccess when uninitialized"
|
||||
" pointer is passed!!");
|
||||
IfTestPassed = false;
|
||||
}
|
||||
}
|
||||
|
||||
SECTION("Passing unusual count size(2nd param)") {
|
||||
|
||||
Yeni konuda referans
Bir kullanıcı engelle